@@ -1,9 +1,5 @@
 package Parse::Lnk;
 
-# Many sections of this code were adapted from:
-# Windows LNK file parser - Jacob Cunningham - jakec76@users.sourceforge.net
-# from the SourceForge project located at:
-# https://sourceforge.net/projects/jafat/files/lnk-parse/lnk-parse-1.0/lnk-parse-1.0.tar.gz
 # Based on the contents of the document:
 # http://www.i2s-lab.com/Papers/The_Windows_Shortcut_File_Format.pdf
 
@@ -12,7 +8,7 @@ use strict;
 use warnings;
 use Carp qw(croak);
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 =pod
 
@@ -24,7 +20,7 @@ Parse::Lnk - A cross-platform, depencency free, Windows shortcut (.lnk) meta dat
 
 =head1 VERSION
 
-Version 0.04
+Version 0.06
 
 =cut
 
@@ -604,9 +600,9 @@ sub _read_null_term {
 This module reads Win32 shortcuts (*.lnk files) to obtain the meta data in them.
 
 Its goal is to be able to resolve the path they point to (along with other data),
-from any platform/OS, without the need for depencencies.
+from any platform/OS, without the need for extra dependencies.
 
-Its use is very simple:
+Some examples of usage:
 
     use Parse::Lnk;
 
@@ -818,6 +814,10 @@ L<https://metacpan.org/release/Parse-Lnk>
 
 =head1 ACKNOWLEDGEMENTS
 
+Many sections of the code were adapted from Jacob Cunningham's
+L<Windows LNK File Parser|https://sourceforge.net/projects/jafat/files/lnk-parse/lnk-parse-1.0/lnk-parse-1.0.tar.gz>,
+licensed under the GNU General Public License Version 2.
+
 
 =head1 LICENSE AND COPYRIGHT
 
